@@ -34,7 +34,8 @@ def segment(
     :type text: str
     :param dict_name: Path to dictionary, defaults to "default"
     :type dict_name: str, optional
-    :param safe: Use safe mode to avoid extra long waiting time in long text,
+    :param safe: Use safe mode to avoid long waiting time in
+        a text with lots of ambiguous word boundaries,
         defaults to False
     :type safe: bool, optional
     :param parallel: Use multithread mode, defaults to False
